Learn R Programming

fCertificates (version 0.5-2)

AirbagPlusCertificate: Airbag Plus Certificate valuation using pricing by duplication

Description

This function values a Airbag Plus certificate using pricing by duplication and the Generalized Black/Scholes formula.

Usage

AirbagPlusCertificate(S, X, B, B2, Time, r, r_d, sigma, 
    participation, ratio = 1, barrierHit = FALSE)

Arguments

S
the asset price, a numeric value.
X
the exercise price ("Partizipationslevel"), a numeric value.
B
the barrier ("Sicherheitslevel"), a numeric value.
B2
the second barrier ("Bonus-Barriere"), a numeric value.
Time
time to maturity measured in years
r
the annualized rate of interest, a numeric value; e.g. 0.25 means 25% pa.
r_d
the annualized dividend yield, a numeric value; e.g. 0.25 means 25% pa.
sigma
the annualized volatility of the underlying security, a numeric value; e.g. 0.3 means 30% volatility pa.
participation
participation rate/factor above strike level. Defaults to 1.
ratio
ratio, number of underlyings one certificate refers to, a numeric value; e.g. 0.25 means 4 certificates refer to 1 share of the underlying asset
barrierHit
flag whether the barrier has already been reached/hit during the lifetime. Defaults to FALSE.

Value

  • the price (scalar or vector) of the AirbagPlusCertificate

Details

An Airbag Certificate is a combination of
  1. a fixed component X
  2. a long call with strike price X
  3. X/B short puts with strike price equal to B.
  4. a down-and-out-put with barrier B2

References

SVSP Swiss Derivative Map 2008 http://www.svsp-verband.ch/

See Also

AirbagCertificate

Examples

Run this code
##
AirbagPlusCertificate(S=100, X=100, B=75, B2=60, Time=0, r=0.045, r_d=0, sigma=0.2, 
  participation=1, ratio=1)
  
## payoff diagram
S <- seq(0,120)
p <- AirbagPlusCertificate(S, X=100, B=75, B2=60, Time=1, r=0.045, r_d=0, sigma=0.2, 
  participation=1, ratio=1)
p2 <- AirbagPlusCertificate(S, X=100, B=75, B2=60, Time=0, r=0.045, r_d=0, sigma=0.2, 
  participation=1, ratio=1)  
plot(S, p, ylim=range(p1, p2, na.rm=TRUE), type="l", col="red", 
  xlab="underlying price", ylab="payoff", main="Airbag Plus")
lines(S, p2, col="blue")  
abline(v=c(60, 75, 100), lty=2, col="gray80")

Run the code above in your browser using DataLab